@@ -54,22 +54,6 @@ CREATE TABLE MASTER_KEYS
 
 ALTER TABLE MASTER_KEYS ADD CONSTRAINT MASTER_KEYS_PK PRIMARY KEY (KEY_ID);
 
--- Table IDXS for classes [org.apache.hadoop.hive.metastore.model.MIndex]
-CREATE TABLE IDXS
-(
-    INDEX_ID bigint NOT NULL,
-    CREATE_TIME int NOT NULL,
-    DEFERRED_REBUILD bit NOT NULL,
-    INDEX_HANDLER_CLASS nvarchar(4000) NULL,
-    INDEX_NAME nvarchar(128) NULL,
-    INDEX_TBL_ID bigint NULL,
-    LAST_ACCESS_TIME int NOT NULL,
-    ORIG_TBL_ID bigint NULL,
-    SD_ID bigint NULL
-);
-
-ALTER TABLE IDXS ADD CONSTRAINT IDXS_PK PRIMARY KEY (INDEX_ID);
-
 -- Table PART_COL_STATS for classes [org.apache.hadoop.hive.metastore.model.MPartitionColumnStatistics]
 CREATE TABLE PART_COL_STATS
 (
@@ -77,7 +61,6 @@ CREATE TABLE PART_COL_STATS
     AVG_COL_LEN float NULL,
     "COLUMN_NAME" nvarchar(767) NOT NULL,
     COLUMN_TYPE nvarchar(128) NOT NULL,
-    DB_NAME nvarchar(128) NOT NULL,
     BIG_DECIMAL_HIGH_VALUE nvarchar(255) NULL,
     BIG_DECIMAL_LOW_VALUE nvarchar(255) NULL,
     DOUBLE_HIGH_VALUE float NULL,
@@ -92,14 +75,13 @@ CREATE TABLE PART_COL_STATS
     NUM_NULLS bigint NOT NULL,
     NUM_TRUES bigint NULL,
     PART_ID bigint NULL,
-    PARTITION_NAME nvarchar(767) NOT NULL,
-    "TABLE_NAME" nvarchar(256) NOT NULL,
-    "CAT_NAME" nvarchar(256) NOT NULL
+    "ENGINE" nvarchar(128) NOT NULL,
+    HISTOGRAM varbinary(max) NULL
 );
 
 ALTER TABLE PART_COL_STATS ADD CONSTRAINT PART_COL_STATS_PK PRIMARY KEY (CS_ID);
 
-CREATE INDEX PCS_STATS_IDX ON PART_COL_STATS (CAT_NAME, DB_NAME,TABLE_NAME,COLUMN_NAME,PARTITION_NAME);
+CREATE INDEX PCS_STATS_IDX ON PART_COL_STATS (PART_ID,COLUMN_NAME);
 
 -- Table PART_PRIVS for classes [org.apache.hadoop.hive.metastore.model.MPartitionPrivilege]
 CREATE TABLE PART_PRIVS
@@ -145,8 +127,8 @@ CREATE TABLE PARTITIONS
     LAST_ACCESS_TIME int NOT NULL,
     PART_NAME nvarchar(767) NULL,
     SD_ID bigint NULL,
-    TBL_ID bigint NULL
-);
+    TBL_ID bigint NULL,
+    WRITE_ID bigint  NOT NULL DEFAULT 0);
 
 ALTER TABLE PARTITIONS ADD CONSTRAINT PARTITIONS_PK PRIMARY KEY (PART_ID);
 
@@ -219,6 +201,24 @@ CREATE TABLE DB_PRIVS
 
 ALTER TABLE DB_PRIVS ADD CONSTRAINT DB_PRIVS_PK PRIMARY KEY (DB_GRANT_ID);
 
+-- Table DC_PRIVS for classes [org.apache.hadoop.hive.metastore.model.MDCPrivilege]
+CREATE TABLE DC_PRIVS
+(
+    DC_GRANT_ID bigint NOT NULL,
+    CREATE_TIME int NOT NULL,
+    NAME nvarchar(128) NULL,
+    GRANT_OPTION smallint NOT NULL CHECK (GRANT_OPTION IN (0,1)),
+    GRANTOR nvarchar(128) NULL,
+    GRANTOR_TYPE nvarchar(128) NULL,
+    PRINCIPAL_NAME nvarchar(128) NULL,
+    PRINCIPAL_TYPE nvarchar(128) NULL,
+    DC_PRIV nvarchar(128) NULL,
+    AUTHORIZER nvarchar(128) NULL
+);
+
+ALTER TABLE DC_PRIVS ADD CONSTRAINT DC_PRIVS_PK PRIMARY KEY (DC_GRANT_ID);
+
+
 -- Table TAB_COL_STATS for classes [org.apache.hadoop.hive.metastore.model.MTableColumnStatistics]
 CREATE TABLE TAB_COL_STATS
 (
@@ -226,7 +226,6 @@ CREATE TABLE TAB_COL_STATS
     AVG_COL_LEN float NULL,
     "COLUMN_NAME" nvarchar(767) NOT NULL,
     COLUMN_TYPE nvarchar(128) NOT NULL,
-    DB_NAME nvarchar(128) NOT NULL,
     BIG_DECIMAL_HIGH_VALUE nvarchar(255) NULL,
     BIG_DECIMAL_LOW_VALUE nvarchar(255) NULL,
     DOUBLE_HIGH_VALUE float NULL,
@@ -241,12 +240,12 @@ CREATE TABLE TAB_COL_STATS
     NUM_NULLS bigint NOT NULL,
     NUM_TRUES bigint NULL,
     TBL_ID bigint NULL,
-    "TABLE_NAME" nvarchar(256) NOT NULL,
-    "CAT_NAME" nvarchar(256) NOT NULL
+    "ENGINE" nvarchar(128) NOT NULL,
+    HISTOGRAM varbinary(max) NULL
 );
 
 ALTER TABLE TAB_COL_STATS ADD CONSTRAINT TAB_COL_STATS_PK PRIMARY KEY (CS_ID);
-CREATE INDEX TAB_COL_STATS_IDX ON TAB_COL_STATS (CAT_NAME, DB_NAME, TABLE_NAME, COLUMN_NAME);
+CREATE INDEX TAB_COL_STATS_IDX ON TAB_COL_STATS (TBL_ID, COLUMN_NAME);
 
 -- Table TYPES for classes [org.apache.hadoop.hive.metastore.model.MType]
 CREATE TABLE TYPES
@@ -286,7 +285,11 @@ CREATE TABLE DBS
     OWNER_NAME nvarchar(128) NULL,
     OWNER_TYPE nvarchar(10) NULL,
     CTLG_NAME nvarchar(256) DEFAULT 'hive',
-    CREATE_TIME INT
+    CREATE_TIME INT,
+    DB_MANAGED_LOCATION_URI nvarchar(4000) NULL,
+    TYPE nvarchar(32) DEFAULT 'NATIVE' NOT NULL,
+    DATACONNECTOR_NAME nvarchar(128) NULL,
+    REMOTE_DBNAME nvarchar(128) NULL
 );
 
 ALTER TABLE DBS ADD CONSTRAINT DBS_PK PRIMARY KEY (DB_ID);
@@ -377,8 +380,8 @@ CREATE TABLE TBLS
     TBL_TYPE nvarchar(128) NULL,
     VIEW_EXPANDED_TEXT text NULL,
     VIEW_ORIGINAL_TEXT text NULL,
-    IS_REWRITE_ENABLED bit NOT NULL DEFAULT 0
-);
+    IS_REWRITE_ENABLED bit NOT NULL DEFAULT 0,
+    WRITE_ID bigint  NOT NULL DEFAULT 0);
 
 ALTER TABLE TBLS ADD CONSTRAINT TBLS_PK PRIMARY KEY (TBL_ID);
 
@@ -400,9 +403,13 @@ CREATE INDEX MV_UNIQUE_TABLE ON MV_CREATION_METADATA (TBL_NAME,DB_NAME);
 CREATE TABLE MV_TABLES_USED
 (
     MV_CREATION_METADATA_ID bigint NOT NULL,
-    TBL_ID bigint NOT NULL
+    TBL_ID bigint NOT NULL,
+    INSERTED_COUNT bigint NOT NULL DEFAULT 0,
+    UPDATED_COUNT bigint NOT NULL DEFAULT 0,
+    DELETED_COUNT bigint NOT NULL DEFAULT 0
 );
 
+ALTER TABLE MV_TABLES_USED ADD CONSTRAINT MV_TABLES_USED_PK PRIMARY KEY (TBL_ID, MV_CREATION_METADATA_ID);
 ALTER TABLE MV_TABLES_USED WITH CHECK ADD FOREIGN KEY(MV_CREATION_METADATA_ID) REFERENCES MV_CREATION_METADATA (MV_CREATION_METADATA_ID);
 ALTER TABLE MV_TABLES_USED WITH CHECK ADD FOREIGN KEY(TBL_ID) REFERENCES TBLS (TBL_ID);
 
@@ -562,21 +569,11 @@ CREATE TABLE DATABASE_PARAMS
 
 ALTER TABLE DATABASE_PARAMS ADD CONSTRAINT DATABASE_PARAMS_PK PRIMARY KEY (DB_ID,PARAM_KEY);
 
--- Table INDEX_PARAMS for join relationship
-CREATE TABLE INDEX_PARAMS
-(
-    INDEX_ID bigint NOT NULL,
-    PARAM_KEY nvarchar(256) NOT NULL,
-    PARAM_VALUE nvarchar(4000) NULL
-);
-
-ALTER TABLE INDEX_PARAMS ADD CONSTRAINT INDEX_PARAMS_PK PRIMARY KEY (INDEX_ID,PARAM_KEY);
-
 -- Table COLUMNS_V2 for join relationship
 CREATE TABLE COLUMNS_V2
 (
     CD_ID bigint NOT NULL,
-    COMMENT nvarchar(256) NULL,
+    COMMENT nvarchar(4000) NULL,
     "COLUMN_NAME" nvarchar(767) NOT NULL,
     TYPE_NAME varchar(max) NOT NULL,
     INTEGER_IDX int NOT NULL
@@ -629,6 +626,8 @@ CREATE TABLE NOTIFICATION_LOG
 
 ALTER TABLE NOTIFICATION_LOG ADD CONSTRAINT NOTIFICATION_LOG_PK PRIMARY KEY (NL_ID);
 
+CREATE UNIQUE INDEX NOTIFICATION_LOG_EVENT_ID ON NOTIFICATION_LOG (EVENT_ID);
+
 CREATE TABLE NOTIFICATION_SEQUENCE
 (
     NNI_ID bigint NOT NULL,
@@ -637,12 +636,17 @@ CREATE TABLE NOTIFICATION_SEQUENCE
 
 ALTER TABLE NOTIFICATION_SEQUENCE ADD CONSTRAINT NOTIFICATION_SEQUENCE_PK PRIMARY KEY (NNI_ID);
 
+ALTER TABLE NOTIFICATION_SEQUENCE ADD CONSTRAINT ONE_ROW_CONSTRAINT CHECK (NNI_ID = 1);
+
+INSERT INTO NOTIFICATION_SEQUENCE (NNI_ID, NEXT_EVENT_ID) SELECT 1,1 WHERE NOT EXISTS (SELECT NEXT_EVENT_ID FROM NOTIFICATION_SEQUENCE);
+
 -- Tables to manage resource plans.
 
 CREATE TABLE WM_RESOURCEPLAN
 (
     RP_ID bigint NOT NULL,
     "NAME" nvarchar(128) NOT NULL,
+    NS nvarchar(128),
     QUERY_PARALLELISM int,
     STATUS nvarchar(20) NOT NULL,
     DEFAULT_POOL_ID bigint
@@ -709,28 +713,9 @@ CREATE UNIQUE INDEX UNIQUE_CTLG ON CTLGS ("NAME");
 
 -- Constraints for table MASTER_KEYS for class(es) [org.apache.hadoop.hive.metastore.model.MMasterKey]
 
--- Constraints for table IDXS for class(es) [org.apache.hadoop.hive.metastore.model.MIndex]
-ALTER TABLE IDXS ADD CONSTRAINT IDXS_FK1 FOREIGN KEY (INDEX_TBL_ID) REFERENCES TBLS (TBL_ID) ;
-
-ALTER TABLE IDXS ADD CONSTRAINT IDXS_FK2 FOREIGN KEY (SD_ID) REFERENCES SDS (SD_ID) ;
-
-ALTER TABLE IDXS ADD CONSTRAINT IDXS_FK3 FOREIGN KEY (ORIG_TBL_ID) REFERENCES TBLS (TBL_ID) ;
-
-CREATE UNIQUE INDEX UNIQUEINDEX ON IDXS (INDEX_NAME,ORIG_TBL_ID);
-
-CREATE INDEX IDXS_N51 ON IDXS (SD_ID);
-
-CREATE INDEX IDXS_N50 ON IDXS (ORIG_TBL_ID);
-
-CREATE INDEX IDXS_N49 ON IDXS (INDEX_TBL_ID);
-
-
 -- Constraints for table PART_COL_STATS for class(es) [org.apache.hadoop.hive.metastore.model.MPartitionColumnStatistics]
 ALTER TABLE PART_COL_STATS ADD CONSTRAINT PART_COL_STATS_FK1 FOREIGN KEY (PART_ID) REFERENCES PARTITIONS (PART_ID) ;
 
-CREATE INDEX PART_COL_STATS_N49 ON PART_COL_STATS (PART_ID);
-
-
 -- Constraints for table PART_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MPartitionPrivilege]
 ALTER TABLE PART_PRIVS ADD CONSTRAINT PART_PRIVS_FK1 FOREIGN KEY (PART_ID) REFERENCES PARTITIONS (PART_ID) ;
 
@@ -752,9 +737,7 @@ ALTER TABLE PARTITIONS ADD CONSTRAINT PARTITIONS_FK2 FOREIGN KEY (SD_ID) REFEREN
 
 CREATE INDEX PARTITIONS_N49 ON PARTITIONS (SD_ID);
 
-CREATE INDEX PARTITIONS_N50 ON PARTITIONS (TBL_ID);
-
-CREATE UNIQUE INDEX UNIQUEPARTITION ON PARTITIONS (PART_NAME,TBL_ID);
+CREATE UNIQUE INDEX UNIQUEPARTITION ON PARTITIONS (TBL_ID,PART_NAME);
 
 
 -- Constraints for table CDS for class(es) [org.apache.hadoop.hive.metastore.model.MColumnDescriptor]
@@ -784,9 +767,6 @@ CREATE INDEX DB_PRIVS_N49 ON DB_PRIVS (DB_ID);
 -- Constraints for table TAB_COL_STATS for class(es) [org.apache.hadoop.hive.metastore.model.MTableColumnStatistics]
 ALTER TABLE TAB_COL_STATS ADD CONSTRAINT TAB_COL_STATS_FK1 FOREIGN KEY (TBL_ID) REFERENCES TBLS (TBL_ID) ;
 
-CREATE INDEX TAB_COL_STATS_N49 ON TAB_COL_STATS (TBL_ID);
-
-
 -- Constraints for table TYPES for class(es) [org.apache.hadoop.hive.metastore.model.MType]
 CREATE UNIQUE INDEX UNIQUETYPE ON TYPES (TYPE_NAME);
 
@@ -838,9 +818,7 @@ ALTER TABLE TBLS ADD CONSTRAINT TBLS_FK1 FOREIGN KEY (DB_ID) REFERENCES DBS (DB_
 
 CREATE INDEX TBLS_N50 ON TBLS (SD_ID);
 
-CREATE UNIQUE INDEX UNIQUETABLE ON TBLS (TBL_NAME,DB_ID);
-
-CREATE INDEX TBLS_N49 ON TBLS (DB_ID);
+CREATE UNIQUE INDEX UNIQUETABLE ON TBLS (DB_ID,TBL_NAME);
 
 
 -- Constraints for table SDS for class(es) [org.apache.hadoop.hive.metastore.model.MStorageDescriptor]
@@ -936,13 +914,6 @@ ALTER TABLE DATABASE_PARAMS ADD CONSTRAINT DATABASE_PARAMS_FK1 FOREIGN KEY (DB_I
 
 CREATE INDEX DATABASE_PARAMS_N49 ON DATABASE_PARAMS (DB_ID);
 
-
--- Constraints for table INDEX_PARAMS
-ALTER TABLE INDEX_PARAMS ADD CONSTRAINT INDEX_PARAMS_FK1 FOREIGN KEY (INDEX_ID) REFERENCES IDXS (INDEX_ID) ;
-
-CREATE INDEX INDEX_PARAMS_N49 ON INDEX_PARAMS (INDEX_ID);
-
-
 -- Constraints for table COLUMNS_V2
 ALTER TABLE COLUMNS_V2 ADD CONSTRAINT COLUMNS_V2_FK1 FOREIGN KEY (CD_ID) REFERENCES CDS (CD_ID) ;
 
@@ -968,7 +939,7 @@ CREATE INDEX TABLE_PARAMS_N49 ON TABLE_PARAMS (TBL_ID);
 
 -- Constraints for resource plan tables.
 
-CREATE UNIQUE INDEX UNIQUE_WM_RESOURCEPLAN ON WM_RESOURCEPLAN ("NAME");
+CREATE UNIQUE INDEX UNIQUE_WM_RESOURCEPLAN ON WM_RESOURCEPLAN ("NS", "NAME");
 
 CREATE UNIQUE INDEX UNIQUE_WM_POOL ON WM_POOL (RP_ID, PATH);
 
@@ -996,17 +967,30 @@ ALTER TABLE DBS ADD CONSTRAINT "DBS_FK1" FOREIGN KEY ("CTLG_NAME") REFERENCES CT
 CREATE TABLE COMPACTION_QUEUE(
 	CQ_ID bigint NOT NULL,
 	CQ_DATABASE nvarchar(128) NOT NULL,
-	CQ_TABLE nvarchar(128) NOT NULL,
+	CQ_TABLE nvarchar(256) NOT NULL,
 	CQ_PARTITION nvarchar(767) NULL,
 	CQ_STATE char(1) NOT NULL,
 	CQ_TYPE char(1) NOT NULL,
 	CQ_TBLPROPERTIES nvarchar(2048) NULL,
 	CQ_WORKER_ID nvarchar(128) NULL,
+	CQ_ENQUEUE_TIME bigint NULL,
 	CQ_START bigint NULL,
 	CQ_RUN_AS nvarchar(128) NULL,
     CQ_HIGHEST_WRITE_ID bigint NULL,
     CQ_META_INFO varbinary(2048) NULL,
 	CQ_HADOOP_JOB_ID nvarchar(128) NULL,
+	CQ_ERROR_MESSAGE varchar(max) NULL,
+    CQ_NEXT_TXN_ID bigint NULL,
+    CQ_TXN_ID bigint NULL,
+    CQ_COMMIT_TIME bigint NULL,
+    CQ_INITIATOR_ID nvarchar(128) NULL,
+    CQ_INITIATOR_VERSION nvarchar(128) NULL,
+    CQ_WORKER_VERSION nvarchar(128) NULL,
+	CQ_CLEANER_START bigint NULL,
+	CQ_RETRY_RETENTION bigint NOT NULL DEFAULT 0,
+    CQ_POOL_NAME nvarchar(128) NULL,
+    CQ_NUMBER_OF_BUCKETS integer,
+    CQ_ORDER_BY varchar(4000),
 PRIMARY KEY CLUSTERED
 (
 	CQ_ID ASC
@@ -1016,34 +1000,58 @@ PRIMARY KEY CLUSTERED
 CREATE TABLE COMPLETED_COMPACTIONS (
 	CC_ID bigint NOT NULL,
 	CC_DATABASE nvarchar(128) NOT NULL,
-	CC_TABLE nvarchar(128) NOT NULL,
+	CC_TABLE nvarchar(256) NOT NULL,
 	CC_PARTITION nvarchar(767) NULL,
 	CC_STATE char(1) NOT NULL,
 	CC_TYPE char(1) NOT NULL,
 	CC_TBLPROPERTIES nvarchar(2048) NULL,
 	CC_WORKER_ID nvarchar(128) NULL,
+	CC_ENQUEUE_TIME bigint NULL,
 	CC_START bigint NULL,
 	CC_END bigint NULL,
 	CC_RUN_AS nvarchar(128) NULL,
     CC_HIGHEST_WRITE_ID bigint NULL,
     CC_META_INFO varbinary(2048) NULL,
 	CC_HADOOP_JOB_ID nvarchar(128) NULL,
+	CC_ERROR_MESSAGE varchar(max) NULL,
+	CC_NEXT_TXN_ID bigint NULL,
+    CC_TXN_ID bigint NULL,
+    CC_COMMIT_TIME bigint NULL,
+    CC_INITIATOR_ID nvarchar(128) NULL,
+    CC_INITIATOR_VERSION nvarchar(128) NULL,
+    CC_WORKER_VERSION nvarchar(128) NULL,
+    CC_POOL_NAME nvarchar(128) NULL,
+    CC_NUMBER_OF_BUCKETS integer,
+    CC_ORDER_BY varchar(4000),
 PRIMARY KEY CLUSTERED
 (
 	CC_ID ASC
 )
 );
 
+CREATE INDEX COMPLETED_COMPACTIONS_RES ON COMPLETED_COMPACTIONS (CC_DATABASE,CC_TABLE,CC_PARTITION);
+
+-- HIVE-25842
+CREATE TABLE COMPACTION_METRICS_CACHE (
+    CMC_DATABASE nvarchar(128) NOT NULL,
+    CMC_TABLE nvarchar(256) NOT NULL,
+    CMC_PARTITION nvarchar(767) NULL,
+    CMC_METRIC_TYPE nvarchar(128) NOT NULL,
+    CMC_METRIC_VALUE int NOT NULL,
+    CMC_VERSION int NOT NULL
+);
+
 CREATE TABLE COMPLETED_TXN_COMPONENTS(
 	CTC_TXNID bigint NOT NULL,
 	CTC_DATABASE nvarchar(128) NOT NULL,
-	CTC_TABLE nvarchar(128) NULL,
+	CTC_TABLE nvarchar(256) NULL,
 	CTC_PARTITION nvarchar(767) NULL,
     CTC_TIMESTAMP datetime2 DEFAULT CURRENT_TIMESTAMP NOT NULL,
     CTC_WRITEID bigint,
     CTC_UPDATE_DELETE char(1) NOT NULL
 );
 
+
 CREATE INDEX COMPLETED_TXN_COMPONENTS_IDX ON COMPLETED_TXN_COMPONENTS (CTC_DATABASE, CTC_TABLE, CTC_PARTITION);
 
 CREATE TABLE HIVE_LOCKS(
@@ -1051,7 +1059,7 @@ CREATE TABLE HIVE_LOCKS(
 	HL_LOCK_INT_ID bigint NOT NULL,
 	HL_TXNID bigint NOT NULL,
 	HL_DB nvarchar(128) NOT NULL,
-	HL_TABLE nvarchar(128) NULL,
+	HL_TABLE nvarchar(256) NULL,
 	HL_PARTITION nvarchar(767) NULL,
 	HL_LOCK_STATE char(1) NOT NULL,
 	HL_LOCK_TYPE char(1) NOT NULL,
@@ -1082,33 +1090,36 @@ CREATE TABLE NEXT_LOCK_ID(
 
 INSERT INTO NEXT_LOCK_ID VALUES(1);
 
-CREATE TABLE NEXT_TXN_ID(
-	NTXN_NEXT bigint NOT NULL
+CREATE TABLE TXN_LOCK_TBL(
+    TXN_LOCK bigint NOT NULL
 );
 
-INSERT INTO NEXT_TXN_ID VALUES(1);
+INSERT INTO TXN_LOCK_TBL VALUES(1);
 
 CREATE TABLE TXNS(
-	TXN_ID bigint NOT NULL,
-	TXN_STATE char(1) NOT NULL,
-	TXN_STARTED bigint NOT NULL,
-	TXN_LAST_HEARTBEAT bigint NOT NULL,
-	TXN_USER nvarchar(128) NOT NULL,
-	TXN_HOST nvarchar(128) NOT NULL,
+    TXN_ID bigint NOT NULL IDENTITY(1,1),
+    TXN_STATE char(1) NOT NULL,
+    TXN_STARTED bigint NOT NULL,
+    TXN_LAST_HEARTBEAT bigint NOT NULL,
+    TXN_USER nvarchar(128) NOT NULL,
+    TXN_HOST nvarchar(128) NOT NULL,
     TXN_AGENT_INFO nvarchar(128) NULL,
     TXN_META_INFO nvarchar(128) NULL,
     TXN_HEARTBEAT_COUNT int NULL,
     TXN_TYPE int NULL,
 PRIMARY KEY CLUSTERED
 (
-	TXN_ID ASC
+    TXN_ID ASC
 )
 );
+SET IDENTITY_INSERT TXNS ON;
+INSERT INTO TXNS (TXN_ID, TXN_STATE, TXN_STARTED, TXN_LAST_HEARTBEAT, TXN_USER, TXN_HOST)
+  VALUES(0, 'c', 0, 0, '', '');
 
 CREATE TABLE TXN_COMPONENTS(
 	TC_TXNID bigint NOT NULL,
 	TC_DATABASE nvarchar(128) NOT NULL,
-	TC_TABLE nvarchar(128) NULL,
+	TC_TABLE nvarchar(256) NULL,
 	TC_PARTITION nvarchar(767) NULL,
     TC_OPERATION_TYPE char(1) NOT NULL,
     TC_WRITEID bigint
@@ -1144,9 +1155,9 @@ CREATE TABLE KEY_CONSTRAINTS
   DELETE_RULE SMALLINT,
   ENABLE_VALIDATE_RELY SMALLINT NOT NULL,
   DEFAULT_VALUE VARCHAR(400)
-) ;
+);
 
-ALTER TABLE KEY_CONSTRAINTS ADD CONSTRAINT CONSTRAINTS_PK PRIMARY KEY (CONSTRAINT_NAME, POSITION);
+ALTER TABLE KEY_CONSTRAINTS ADD CONSTRAINT CONSTRAINTS_PK PRIMARY KEY (PARENT_TBL_ID, CONSTRAINT_NAME, POSITION);
 
 CREATE INDEX CONSTRAINTS_PARENT_TBL_ID__INDEX ON KEY_CONSTRAINTS(PARENT_TBL_ID);
 
@@ -1154,7 +1165,7 @@ CREATE INDEX CONSTRAINTS_CONSTRAINT_TYPE_INDEX ON KEY_CONSTRAINTS(CONSTRAINT_TYP
 
 CREATE TABLE WRITE_SET (
   WS_DATABASE nvarchar(128) NOT NULL,
-  WS_TABLE nvarchar(128) NOT NULL,
+  WS_TABLE nvarchar(256) NOT NULL,
   WS_PARTITION nvarchar(767),
   WS_TXNID bigint NOT NULL,
   WS_COMMIT_ID bigint NOT NULL,
@@ -1164,7 +1175,8 @@ CREATE TABLE WRITE_SET (
 CREATE TABLE METASTORE_DB_PROPERTIES (
   PROPERTY_KEY VARCHAR(255) NOT NULL,
   PROPERTY_VALUE VARCHAR(1000) NOT NULL,
-  DESCRIPTION VARCHAR(1000)
+  DESCRIPTION VARCHAR(1000),
+  PROPERTYCONTENT varbinary(max)
 );
 
 ALTER TABLE METASTORE_DB_PROPERTIES ADD CONSTRAINT PROPERTY_KEY_PK PRIMARY KEY (PROPERTY_KEY);
@@ -1187,6 +1199,13 @@ CREATE TABLE NEXT_WRITE_ID (
 
 CREATE UNIQUE INDEX NEXT_WRITE_ID_IDX ON NEXT_WRITE_ID (NWI_DATABASE, NWI_TABLE);
 
+CREATE TABLE MIN_HISTORY_WRITE_ID (
+  MH_TXNID bigint NOT NULL,
+  MH_DATABASE nvarchar(128) NOT NULL,
+  MH_TABLE nvarchar(256) NOT NULL,
+  MH_WRITEID bigint NOT NULL
+);
+
 CREATE TABLE MIN_HISTORY_LEVEL (
   MHL_TXNID bigint NOT NULL,
   MHL_MIN_OPEN_TXNID bigint NOT NULL,
@@ -1271,7 +1290,7 @@ CREATE TABLE TXN_WRITE_NOTIFICATION_LOG (
   WNL_TXNID bigint NOT NULL,
   WNL_WRITEID bigint NOT NULL,
   WNL_DATABASE nvarchar(128) NOT NULL,
-  WNL_TABLE nvarchar(128) NOT NULL,
+  WNL_TABLE nvarchar(256) NOT NULL,
   WNL_PARTITION nvarchar(767) NOT NULL,
   WNL_TABLE_OBJ text NOT NULL,
   WNL_PARTITION_OBJ text,
@@ -1283,7 +1302,119 @@ ALTER TABLE TXN_WRITE_NOTIFICATION_LOG ADD CONSTRAINT TXN_WRITE_NOTIFICATION_LOG
 
 INSERT INTO SEQUENCE_TABLE (SEQUENCE_NAME, NEXT_VAL) VALUES ('org.apache.hadoop.hive.metastore.model.MTxnWriteNotificationLog', 1);
 
+CREATE TABLE "SCHEDULED_QUERIES" (
+	"SCHEDULED_QUERY_ID"  bigint NOT NULL,
+	"CLUSTER_NAMESPACE" VARCHAR(256),
+	"ENABLED" bit NOT NULL DEFAULT 0,
+	"NEXT_EXECUTION" INTEGER,
+	"QUERY" VARCHAR(4000),
+	"SCHEDULE" VARCHAR(256),
+	"SCHEDULE_NAME" VARCHAR(256),
+	"USER" VARCHAR(256),
+	"ACTIVE_EXECUTION_ID" bigint,
+	CONSTRAINT SCHEDULED_QUERIES_PK PRIMARY KEY ("SCHEDULED_QUERY_ID")
+);
+
+CREATE TABLE "SCHEDULED_EXECUTIONS" (
+	"SCHEDULED_EXECUTION_ID" bigint NOT NULL,
+	"END_TIME" INTEGER,
+	"ERROR_MESSAGE" VARCHAR(2000),
+	"EXECUTOR_QUERY_ID" VARCHAR(256),
+	"LAST_UPDATE_TIME" INTEGER,
+	"SCHEDULED_QUERY_ID" bigint,
+	"START_TIME" INTEGER,
+	"STATE" VARCHAR(256),
+	CONSTRAINT SCHEDULED_EXECUTIONS_PK PRIMARY KEY ("SCHEDULED_EXECUTION_ID"),
+	CONSTRAINT SCHEDULED_EXECUTIONS_SCHQ_FK FOREIGN KEY ("SCHEDULED_QUERY_ID") REFERENCES "SCHEDULED_QUERIES"("SCHEDULED_QUERY_ID") ON DELETE CASCADE
+);
+
+CREATE INDEX IDX_SCHEDULED_EX_LAST_UPDATE ON "SCHEDULED_EXECUTIONS" ("LAST_UPDATE_TIME");
+CREATE INDEX IDX_SCHEDULED_EX_SQ_ID ON "SCHEDULED_EXECUTIONS" ("SCHEDULED_QUERY_ID");
+
+-- HIVE-23516
+CREATE TABLE "REPLICATION_METRICS" (
+  "RM_SCHEDULED_EXECUTION_ID" bigint PRIMARY KEY,
+  "RM_POLICY" varchar(256) NOT NULL,
+  "RM_DUMP_EXECUTION_ID" bigint NOT NULL,
+  "RM_METADATA" varchar(max),
+  "RM_PROGRESS" varchar(max),
+  "RM_START_TIME" integer NOT NULL,
+  "MESSAGE_FORMAT" nvarchar(16) DEFAULT 'json-0.2',
+);
+
+-- Create indexes for the replication metrics table
+CREATE INDEX "POLICY_IDX" ON "REPLICATION_METRICS" ("RM_POLICY");
+CREATE INDEX "DUMP_IDX" ON "REPLICATION_METRICS" ("RM_DUMP_EXECUTION_ID");
+
+-- Create stored procedure tables
+CREATE TABLE "STORED_PROCS" (
+  "SP_ID" BIGINT NOT NULL,
+  "CREATE_TIME" int NOT NULL,
+  "DB_ID" BIGINT NOT NULL,
+  "NAME" nvarchar(256) NOT NULL,
+  "OWNER_NAME" nvarchar(128) NOT NULL,
+  "SOURCE" NTEXT NOT NULL,
+  PRIMARY KEY ("SP_ID")
+);
+
+CREATE UNIQUE INDEX "UNIQUESTOREDPROC" ON "STORED_PROCS" ("NAME", "DB_ID");
+ALTER TABLE "STORED_PROCS" ADD CONSTRAINT "STOREDPROC_FK1" FOREIGN KEY ("DB_ID") REFERENCES "DBS" ("DB_ID");
+
+
+-- Create stored procedure packages
+CREATE TABLE "PACKAGES" (
+  "PKG_ID" BIGINT NOT NULL,
+  "CREATE_TIME" int NOT NULL,
+  "DB_ID" BIGINT NOT NULL,
+  "NAME" nvarchar(256) NOT NULL,
+  "OWNER_NAME" nvarchar(128) NOT NULL,
+  "HEADER" NTEXT NOT NULL,
+  "BODY" NTEXT NOT NULL,
+  PRIMARY KEY ("PKG_ID")
+);
+
+CREATE UNIQUE INDEX "UNIQUEPKG" ON "PACKAGES" ("NAME", "DB_ID");
+ALTER TABLE "PACKAGES" ADD CONSTRAINT "PACKAGES_FK1" FOREIGN KEY ("DB_ID") REFERENCES "DBS" ("DB_ID");
+
+-- HIVE-24396
+-- Create DataConnectors and DataConnector_Params tables
+CREATE TABLE "DATACONNECTORS" (
+  "NAME" nvarchar(128) NOT NULL,
+  "TYPE" nvarchar(32) NOT NULL,
+  "URL" nvarchar(4000) NOT NULL,
+  "COMMENT" nvarchar(256),
+  "OWNER_NAME" nvarchar(256),
+  "OWNER_TYPE" nvarchar(10),
+  "CREATE_TIME" int NOT NULL,
+  PRIMARY KEY ("NAME")
+);
+
+CREATE TABLE "DATACONNECTOR_PARAMS"(
+  "NAME" nvarchar(128) NOT NULL,
+  "PARAM_KEY" nvarchar(180) NOT NULL,
+  "PARAM_VALUE" nvarchar(4000),
+  PRIMARY KEY ("NAME", "PARAM_KEY"),
+  CONSTRAINT DATACONNECTOR_NAME_FK1 FOREIGN KEY ("NAME") REFERENCES "DATACONNECTORS" ("NAME") ON DELETE CASCADE
+);
+
+-- Constraints for table DC_PRIVS for class(es) [org.apache.hadoop.hive.metastore.model.MDCPrivilege]
+ALTER TABLE DC_PRIVS ADD CONSTRAINT DC_PRIVS_FK1 FOREIGN KEY (NAME) REFERENCES DATACONNECTORS (NAME) ;
+
+CREATE UNIQUE INDEX DCPRIVILEGEINDEX ON DC_PRIVS (AUTHORIZER,NAME,PRINCIPAL_NAME,PRINCIPAL_TYPE,DC_PRIV,GRANTOR,GRANTOR_TYPE);
+
+CREATE INDEX DC_PRIVS_N49 ON DC_PRIVS (NAME);
+
+-- HIVE-29178
+-- Table structure for table CATALOG_PARAMS
+CREATE TABLE CATALOG_PARAMS (
+     CTLG_ID bigint NOT NULL,
+     PARAM_KEY nvarchar(180) NOT NULL,
+     PARAM_VALUE nvarchar(4000) DEFAULT NULL,
+     PRIMARY KEY (CTLG_ID, PARAM_KEY),
+     CONSTRAINT CATALOG_PARAMS_FK1 FOREIGN KEY (CTLG_ID) REFERENCES CTLGS (CTLG_ID) ON DELETE CASCADE
+);
+
 -- -----------------------------------------------------------------
 -- Record schema version. Should be the last step in the init script
 -- -----------------------------------------------------------------
-INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '3.2.0', 'Hive release version 3.2.0');
+INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '4.2.0', 'Hive release version 4.2.0');
