@@ -52,8 +52,8 @@ CREATE TABLE IF NOT EXISTS `CDS` (
 CREATE TABLE IF NOT EXISTS `COLUMNS_V2` (
   `CD_ID` bigint(20) NOT NULL,
   `COMMENT` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `COLUMN_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
-  `TYPE_NAME` MEDIUMTEXT DEFAULT NULL,
+  `COLUMN_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
+  `TYPE_NAME` varchar(4000) DEFAULT NULL,
   `INTEGER_IDX` int(11) NOT NULL,
   PRIMARY KEY (`CD_ID`,`COLUMN_NAME`),
   KEY `COLUMNS_V2_N49` (`CD_ID`),
@@ -77,15 +77,6 @@ CREATE TABLE IF NOT EXISTS `DATABASE_PARAMS` (
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
-CREATE TABLE `CTLGS` (
-    `CTLG_ID` BIGINT PRIMARY KEY,
-    `NAME` VARCHAR(256),
-    `DESC` VARCHAR(4000),
-    `LOCATION_URI` VARCHAR(4000) NOT NULL,
-    UNIQUE KEY `UNIQUE_CATALOG` (`NAME`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-
 --
 -- Table structure for table `DBS`
 --
@@ -99,10 +90,8 @@ CREATE TABLE IF NOT EXISTS `DBS` (
   `NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `OWNER_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `OWNER_TYPE` varchar(10) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `CTLG_NAME` varchar(256) NOT NULL,
   PRIMARY KEY (`DB_ID`),
-  UNIQUE KEY `UNIQUE_DATABASE` (`NAME`, `CTLG_NAME`),
-  CONSTRAINT `CTLG_FK1` FOREIGN KEY (`CTLG_NAME`) REFERENCES `CTLGS` (`NAME`)
+  UNIQUE KEY `UNIQUE_DATABASE` (`NAME`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
@@ -222,12 +211,15 @@ CREATE TABLE IF NOT EXISTS `PARTITIONS` (
   `PART_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `SD_ID` bigint(20) DEFAULT NULL,
   `TBL_ID` bigint(20) DEFAULT NULL,
+  `LINK_TARGET_ID` bigint(20) DEFAULT NULL,
   PRIMARY KEY (`PART_ID`),
   UNIQUE KEY `UNIQUEPARTITION` (`PART_NAME`,`TBL_ID`),
   KEY `PARTITIONS_N49` (`TBL_ID`),
   KEY `PARTITIONS_N50` (`SD_ID`),
+  KEY `PARTITIONS_N51` (`LINK_TARGET_ID`),
   CONSTRAINT `PARTITIONS_FK1` FOREIGN KEY (`TBL_ID`) REFERENCES `TBLS` (`TBL_ID`),
-  CONSTRAINT `PARTITIONS_FK2` FOREIGN KEY (`SD_ID`) REFERENCES `SDS` (`SD_ID`)
+  CONSTRAINT `PARTITIONS_FK2` FOREIGN KEY (`SD_ID`) REFERENCES `SDS` (`SD_ID`),
+  CONSTRAINT `PARTITIONS_FK3` FOREIGN KEY (`LINK_TARGET_ID`) REFERENCES `PARTITIONS` (`PART_ID`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
@@ -239,12 +231,11 @@ CREATE TABLE IF NOT EXISTS `PARTITIONS` (
 /*!40101 SET character_set_client = utf8 */;
 CREATE TABLE IF NOT EXISTS `PARTITION_EVENTS` (
   `PART_NAME_ID` bigint(20) NOT NULL,
-  `CAT_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `DB_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `EVENT_TIME` bigint(20) NOT NULL,
   `EVENT_TYPE` int(11) NOT NULL,
   `PARTITION_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `TBL_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `TBL_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   PRIMARY KEY (`PART_NAME_ID`),
   KEY `PARTITIONEVENTINDEX` (`PARTITION_NAME`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
@@ -308,7 +299,7 @@ CREATE TABLE IF NOT EXISTS `PARTITION_PARAMS` (
 /*!40101 SET character_set_client = utf8 */;
 CREATE TABLE IF NOT EXISTS `PART_COL_PRIVS` (
   `PART_COLUMN_GRANT_ID` bigint(20) NOT NULL,
-  `COLUMN_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `COLUMN_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `CREATE_TIME` int(11) NOT NULL,
   `GRANT_OPTION` smallint(6) NOT NULL,
   `GRANTOR` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
@@ -418,7 +409,7 @@ CREATE TABLE IF NOT EXISTS `SDS` (
 CREATE TABLE IF NOT EXISTS `SD_PARAMS` (
   `SD_ID` bigint(20) NOT NULL,
   `PARAM_KEY` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
-  `PARAM_VALUE` MEDIUMTEXT CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `PARAM_VALUE` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   PRIMARY KEY (`SD_ID`,`PARAM_KEY`),
   KEY `SD_PARAMS_N49` (`SD_ID`),
   CONSTRAINT `SD_PARAMS_FK1` FOREIGN KEY (`SD_ID`) REFERENCES `SDS` (`SD_ID`)
@@ -438,8 +429,6 @@ CREATE TABLE IF NOT EXISTS `SEQUENCE_TABLE` (
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
-INSERT INTO `SEQUENCE_TABLE` (`SEQUENCE_NAME`, `NEXT_VAL`) VALUES ('org.apache.hadoop.hive.metastore.model.MNotificationLog', 1);
-
 --
 -- Table structure for table `SERDES`
 --
@@ -450,10 +439,6 @@ CREATE TABLE IF NOT EXISTS `SERDES` (
   `SERDE_ID` bigint(20) NOT NULL,
   `NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `SLIB` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `DESCRIPTION` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `SERIALIZER_CLASS` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `DESERIALIZER_CLASS` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `SERDE_TYPE` integer,
   PRIMARY KEY (`SERDE_ID`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 /*!40101 SET character_set_client = @saved_cs_client */;
@@ -467,7 +452,7 @@ CREATE TABLE IF NOT EXISTS `SERDES` (
 CREATE TABLE IF NOT EXISTS `SERDE_PARAMS` (
   `SERDE_ID` bigint(20) NOT NULL,
   `PARAM_KEY` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
-  `PARAM_VALUE` MEDIUMTEXT CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `PARAM_VALUE` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   PRIMARY KEY (`SERDE_ID`,`PARAM_KEY`),
   KEY `SERDE_PARAMS_N49` (`SERDE_ID`),
   CONSTRAINT `SERDE_PARAMS_FK1` FOREIGN KEY (`SERDE_ID`) REFERENCES `SERDES` (`SERDE_ID`)
@@ -562,7 +547,7 @@ CREATE TABLE IF NOT EXISTS `SKEWED_VALUES` (
 /*!40101 SET character_set_client = utf8 */;
 CREATE TABLE IF NOT EXISTS `SORT_COLS` (
   `SD_ID` bigint(20) NOT NULL,
-  `COLUMN_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `COLUMN_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `ORDER` int(11) NOT NULL,
   `INTEGER_IDX` int(11) NOT NULL,
   PRIMARY KEY (`SD_ID`,`INTEGER_IDX`),
@@ -580,31 +565,13 @@ CREATE TABLE IF NOT EXISTS `SORT_COLS` (
 CREATE TABLE IF NOT EXISTS `TABLE_PARAMS` (
   `TBL_ID` bigint(20) NOT NULL,
   `PARAM_KEY` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
-  `PARAM_VALUE` MEDIUMTEXT CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `PARAM_VALUE` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   PRIMARY KEY (`TBL_ID`,`PARAM_KEY`),
   KEY `TABLE_PARAMS_N49` (`TBL_ID`),
   CONSTRAINT `TABLE_PARAMS_FK1` FOREIGN KEY (`TBL_ID`) REFERENCES `TBLS` (`TBL_ID`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
---
--- Table structure for table `MV_CREATION_METADATA`
---
-
-/*!40101 SET @saved_cs_client     = @@character_set_client */;
-/*!40101 SET character_set_client = utf8 */;
-CREATE TABLE IF NOT EXISTS `MV_CREATION_METADATA` (
-  `MV_CREATION_METADATA_ID` bigint(20) NOT NULL,
-  `CAT_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
-  `DB_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
-  `TBL_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
-  `TXN_LIST` TEXT DEFAULT NULL,
-  PRIMARY KEY (`MV_CREATION_METADATA_ID`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-/*!40101 SET character_set_client = @saved_cs_client */;
-
-CREATE INDEX MV_UNIQUE_TABLE ON MV_CREATION_METADATA (TBL_NAME, DB_NAME) USING BTREE;
-
 --
 -- Table structure for table `TBLS`
 --
@@ -617,34 +584,21 @@ CREATE TABLE IF NOT EXISTS `TBLS` (
   `DB_ID` bigint(20) DEFAULT NULL,
   `LAST_ACCESS_TIME` int(11) NOT NULL,
   `OWNER` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
-  `OWNER_TYPE` varchar(10) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `RETENTION` int(11) NOT NULL,
   `SD_ID` bigint(20) DEFAULT NULL,
-  `TBL_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `TBL_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `TBL_TYPE` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `VIEW_EXPANDED_TEXT` mediumtext,
   `VIEW_ORIGINAL_TEXT` mediumtext,
-  `IS_REWRITE_ENABLED` bit(1) NOT NULL DEFAULT 0,
+  `LINK_TARGET_ID` bigint(20) DEFAULT NULL,
   PRIMARY KEY (`TBL_ID`),
   UNIQUE KEY `UNIQUETABLE` (`TBL_NAME`,`DB_ID`),
   KEY `TBLS_N50` (`SD_ID`),
   KEY `TBLS_N49` (`DB_ID`),
+  KEY `TBLS_N51` (`LINK_TARGET_ID`),
   CONSTRAINT `TBLS_FK1` FOREIGN KEY (`SD_ID`) REFERENCES `SDS` (`SD_ID`),
-  CONSTRAINT `TBLS_FK2` FOREIGN KEY (`DB_ID`) REFERENCES `DBS` (`DB_ID`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-/*!40101 SET character_set_client = @saved_cs_client */;
-
---
--- Table structure for table `MV_TABLES_USED`
---
-
-/*!40101 SET @saved_cs_client     = @@character_set_client */;
-/*!40101 SET character_set_client = utf8 */;
-CREATE TABLE IF NOT EXISTS `MV_TABLES_USED` (
-  `MV_CREATION_METADATA_ID` bigint(20) NOT NULL,
-  `TBL_ID` bigint(20) NOT NULL,
-  CONSTRAINT `MV_TABLES_USED_FK1` FOREIGN KEY (`MV_CREATION_METADATA_ID`) REFERENCES `MV_CREATION_METADATA` (`MV_CREATION_METADATA_ID`),
-  CONSTRAINT `MV_TABLES_USED_FK2` FOREIGN KEY (`TBL_ID`) REFERENCES `TBLS` (`TBL_ID`)
+  CONSTRAINT `TBLS_FK2` FOREIGN KEY (`DB_ID`) REFERENCES `DBS` (`DB_ID`),
+  CONSTRAINT `TBLS_FK3` FOREIGN KEY (`LINK_TARGET_ID`) REFERENCES `TBLS` (`TBL_ID`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 /*!40101 SET character_set_client = @saved_cs_client */;
 
@@ -656,7 +610,7 @@ CREATE TABLE IF NOT EXISTS `MV_TABLES_USED` (
 /*!40101 SET character_set_client = utf8 */;
 CREATE TABLE IF NOT EXISTS `TBL_COL_PRIVS` (
   `TBL_COLUMN_GRANT_ID` bigint(20) NOT NULL,
-  `COLUMN_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
+  `COLUMN_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
   `CREATE_TIME` int(11) NOT NULL,
   `GRANT_OPTION` smallint(6) NOT NULL,
   `GRANTOR` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin DEFAULT NULL,
@@ -700,10 +654,9 @@ CREATE TABLE IF NOT EXISTS `TBL_PRIVS` (
 --
 CREATE TABLE IF NOT EXISTS `TAB_COL_STATS` (
  `CS_ID` bigint(20) NOT NULL,
- `CAT_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
  `DB_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
- `TABLE_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
- `COLUMN_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
+ `TABLE_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
+ `COLUMN_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
  `COLUMN_TYPE` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
  `TBL_ID` bigint(20) NOT NULL,
  `LONG_LOW_VALUE` bigint(20),
@@ -714,7 +667,6 @@ CREATE TABLE IF NOT EXISTS `TAB_COL_STATS` (
  `BIG_DECIMAL_HIGH_VALUE` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin,
  `NUM_NULLS` bigint(20) NOT NULL,
  `NUM_DISTINCTS` bigint(20),
- `BIT_VECTOR` blob,
  `AVG_COL_LEN` double(53,4),
  `MAX_COL_LEN` bigint(20),
  `NUM_TRUES` bigint(20),
@@ -729,11 +681,10 @@ CREATE TABLE IF NOT EXISTS `TAB_COL_STATS` (
 --
 CREATE TABLE IF NOT EXISTS `PART_COL_STATS` (
  `CS_ID` bigint(20) NOT NULL,
- `CAT_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
  `DB_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
- `TABLE_NAME` varchar(256) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
+ `TABLE_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
  `PARTITION_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
- `COLUMN_NAME` varchar(767) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
+ `COLUMN_NAME` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
  `COLUMN_TYPE` varchar(128) CHARACTER SET latin1 COLLATE latin1_bin NOT NULL,
  `PART_ID` bigint(20) NOT NULL,
  `LONG_LOW_VALUE` bigint(20),
@@ -744,7 +695,6 @@ CREATE TABLE IF NOT EXISTS `PART_COL_STATS` (
  `BIG_DECIMAL_HIGH_VALUE` varchar(4000) CHARACTER SET latin1 COLLATE latin1_bin,
  `NUM_NULLS` bigint(20) NOT NULL,
  `NUM_DISTINCTS` bigint(20),
- `BIT_VECTOR` blob,
  `AVG_COL_LEN` double(53,4),
  `MAX_COL_LEN` bigint(20),
  `NUM_TRUES` bigint(20),
@@ -754,7 +704,7 @@ CREATE TABLE IF NOT EXISTS `PART_COL_STATS` (
   CONSTRAINT `PART_COL_STATS_FK` FOREIGN KEY (`PART_ID`) REFERENCES `PARTITIONS` (`PART_ID`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
-CREATE INDEX PCS_STATS_IDX ON PART_COL_STATS (CAT_NAME, DB_NAME,TABLE_NAME,COLUMN_NAME,PARTITION_NAME) USING BTREE;
+CREATE INDEX PCS_STATS_IDX ON PART_COL_STATS (DB_NAME,TABLE_NAME,COLUMN_NAME,PARTITION_NAME) USING BTREE;
 
 --
 -- Table structure for table `TYPES`
@@ -790,7 +740,7 @@ CREATE TABLE IF NOT EXISTS `TYPE_FIELDS` (
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
 -- Table `MASTER_KEYS` for classes [org.apache.hadoop.hive.metastore.model.MMasterKey]
-CREATE TABLE IF NOT EXISTS `MASTER_KEYS`
+CREATE TABLE IF NOT EXISTS `MASTER_KEYS` 
 (
     `KEY_ID` INTEGER NOT NULL AUTO_INCREMENT,
     `MASTER_KEY` VARCHAR(767) BINARY NULL,
@@ -851,11 +801,9 @@ CREATE TABLE IF NOT EXISTS `NOTIFICATION_LOG`
     `EVENT_ID` BIGINT(20) NOT NULL,
     `EVENT_TIME` INT(11) NOT NULL,
     `EVENT_TYPE` varchar(32) NOT NULL,
-    `CAT_NAME` varchar(256),
     `DB_NAME` varchar(128),
-    `TBL_NAME` varchar(256),
-    `MESSAGE` longtext,
-    `MESSAGE_FORMAT` varchar(16),
+    `TBL_NAME` varchar(128),
+    `MESSAGE` mediumtext,
     PRIMARY KEY (`NL_ID`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
@@ -866,104 +814,7 @@ CREATE TABLE IF NOT EXISTS `NOTIFICATION_SEQUENCE`
     PRIMARY KEY (`NNI_ID`)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
-INSERT INTO `NOTIFICATION_SEQUENCE` (`NNI_ID`, `NEXT_EVENT_ID`) SELECT * from (select 1 as `NNI_ID`, 1 as `NOTIFICATION_SEQUENCE`) a WHERE (SELECT COUNT(*) FROM `NOTIFICATION_SEQUENCE`) = 0;
 
-CREATE TABLE IF NOT EXISTS `KEY_CONSTRAINTS`
-(
-  `CHILD_CD_ID` BIGINT,
-  `CHILD_INTEGER_IDX` INT(11),
-  `CHILD_TBL_ID` BIGINT,
-  `PARENT_CD_ID` BIGINT,
-  `PARENT_INTEGER_IDX` INT(11) NOT NULL,
-  `PARENT_TBL_ID` BIGINT NOT NULL,
-  `POSITION` BIGINT NOT NULL,
-  `CONSTRAINT_NAME` VARCHAR(400) NOT NULL,
-  `CONSTRAINT_TYPE` SMALLINT(6)  NOT NULL,
-  `UPDATE_RULE` SMALLINT(6),
-  `DELETE_RULE` SMALLINT(6),
-  `ENABLE_VALIDATE_RELY` SMALLINT(6) NOT NULL,
-  `DEFAULT_VALUE` VARCHAR(400),
-  PRIMARY KEY (`CONSTRAINT_NAME`, `POSITION`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE INDEX `CONSTRAINTS_PARENT_TABLE_ID_INDEX` ON KEY_CONSTRAINTS (`PARENT_TBL_ID`) USING BTREE;
-
-CREATE INDEX `CONSTRAINTS_CONSTRAINT_TYPE_INDEX` ON KEY_CONSTRAINTS (`CONSTRAINT_TYPE`) USING BTREE;
-
--- -----------------------------
--- Metastore DB Properties table
--- -----------------------------
-CREATE TABLE IF NOT EXISTS `METASTORE_DB_PROPERTIES` (
-  `PROPERTY_KEY` varchar(255) NOT NULL,
-  `PROPERTY_VALUE` varchar(1000) NOT NULL,
-  `DESCRIPTION` varchar(1000),
- PRIMARY KEY(`PROPERTY_KEY`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-
--- ---------------------
--- Resource plan tables.
--- ---------------------
-CREATE TABLE IF NOT EXISTS WM_RESOURCEPLAN (
-    `RP_ID` bigint(20) NOT NULL,
-    `NAME` varchar(128) NOT NULL,
-    `QUERY_PARALLELISM` int(11),
-    `STATUS` varchar(20) NOT NULL,
-    `DEFAULT_POOL_ID` bigint(20),
-    PRIMARY KEY (`RP_ID`),
-    UNIQUE KEY `UNIQUE_WM_RESOURCEPLAN` (`NAME`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE TABLE IF NOT EXISTS WM_POOL
-(
-    `POOL_ID` bigint(20) NOT NULL,
-    `RP_ID` bigint(20) NOT NULL,
-    `PATH` varchar(767) NOT NULL,
-    `ALLOC_FRACTION` DOUBLE,
-    `QUERY_PARALLELISM` int(11),
-    `SCHEDULING_POLICY` varchar(767),
-    PRIMARY KEY (`POOL_ID`),
-    UNIQUE KEY `UNIQUE_WM_POOL` (`RP_ID`, `PATH`),
-    CONSTRAINT `WM_POOL_FK1` FOREIGN KEY (`RP_ID`) REFERENCES `WM_RESOURCEPLAN` (`RP_ID`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-ALTER TABLE `WM_RESOURCEPLAN` ADD CONSTRAINT `WM_RESOURCEPLAN_FK1` FOREIGN KEY (`DEFAULT_POOL_ID`) REFERENCES `WM_POOL`(`POOL_ID`);
-
-CREATE TABLE IF NOT EXISTS WM_TRIGGER
-(
-    `TRIGGER_ID` bigint(20) NOT NULL,
-    `RP_ID` bigint(20) NOT NULL,
-    `NAME` varchar(128) NOT NULL,
-    `TRIGGER_EXPRESSION` varchar(1024),
-    `ACTION_EXPRESSION` varchar(1024),
-    `IS_IN_UNMANAGED` bit(1) NOT NULL DEFAULT 0,
-    PRIMARY KEY (`TRIGGER_ID`),
-    UNIQUE KEY `UNIQUE_WM_TRIGGER` (`RP_ID`, `NAME`),
-    CONSTRAINT `WM_TRIGGER_FK1` FOREIGN KEY (`RP_ID`) REFERENCES `WM_RESOURCEPLAN` (`RP_ID`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE TABLE IF NOT EXISTS WM_POOL_TO_TRIGGER
-(
-    `POOL_ID` bigint(20) NOT NULL,
-    `TRIGGER_ID` bigint(20) NOT NULL,
-    PRIMARY KEY (`POOL_ID`, `TRIGGER_ID`),
-    CONSTRAINT `WM_POOL_TO_TRIGGER_FK1` FOREIGN KEY (`POOL_ID`) REFERENCES `WM_POOL` (`POOL_ID`),
-    CONSTRAINT `WM_POOL_TO_TRIGGER_FK2` FOREIGN KEY (`TRIGGER_ID`) REFERENCES `WM_TRIGGER` (`TRIGGER_ID`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE TABLE IF NOT EXISTS WM_MAPPING
-(
-    `MAPPING_ID` bigint(20) NOT NULL,
-    `RP_ID` bigint(20) NOT NULL,
-    `ENTITY_TYPE` varchar(128) NOT NULL,
-    `ENTITY_NAME` varchar(128) NOT NULL,
-    `POOL_ID` bigint(20),
-    `ORDERING` int,
-    PRIMARY KEY (`MAPPING_ID`),
-    UNIQUE KEY `UNIQUE_WM_MAPPING` (`RP_ID`, `ENTITY_TYPE`, `ENTITY_NAME`),
-    CONSTRAINT `WM_MAPPING_FK1` FOREIGN KEY (`RP_ID`) REFERENCES `WM_RESOURCEPLAN` (`RP_ID`),
-    CONSTRAINT `WM_MAPPING_FK2` FOREIGN KEY (`POOL_ID`) REFERENCES `WM_POOL` (`POOL_ID`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
 -- ----------------------------
 -- Transaction and Lock Tables
@@ -974,35 +825,24 @@ CREATE TABLE TXNS (
   TXN_STARTED bigint NOT NULL,
   TXN_LAST_HEARTBEAT bigint NOT NULL,
   TXN_USER varchar(128) NOT NULL,
-  TXN_HOST varchar(128) NOT NULL,
-  TXN_AGENT_INFO varchar(128),
-  TXN_META_INFO varchar(128),
-  TXN_HEARTBEAT_COUNT int
+  TXN_HOST varchar(128) NOT NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
 CREATE TABLE TXN_COMPONENTS (
-  TC_TXNID bigint NOT NULL,
+  TC_TXNID bigint,
   TC_DATABASE varchar(128) NOT NULL,
   TC_TABLE varchar(128),
   TC_PARTITION varchar(767),
-  TC_OPERATION_TYPE char(1) NOT NULL,
-  TC_WRITEID bigint,
   FOREIGN KEY (TC_TXNID) REFERENCES TXNS (TXN_ID)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
-CREATE INDEX TC_TXNID_INDEX ON TXN_COMPONENTS (TC_TXNID);
-
 CREATE TABLE COMPLETED_TXN_COMPONENTS (
-  CTC_TXNID bigint NOT NULL,
+  CTC_TXNID bigint,
   CTC_DATABASE varchar(128) NOT NULL,
-  CTC_TABLE varchar(256),
-  CTC_PARTITION varchar(767),
-  CTC_TIMESTAMP timestamp DEFAULT CURRENT_TIMESTAMP NOT NULL,
-  CTC_WRITEID bigint
+  CTC_TABLE varchar(128),
+  CTC_PARTITION varchar(767)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
-CREATE INDEX COMPLETED_TXN_COMPONENTS_IDX ON COMPLETED_TXN_COMPONENTS (CTC_DATABASE, CTC_TABLE, CTC_PARTITION) USING BTREE;
-
 CREATE TABLE NEXT_TXN_ID (
   NTXN_NEXT bigint NOT NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
@@ -1011,7 +851,7 @@ INSERT INTO NEXT_TXN_ID VALUES(1);
 CREATE TABLE HIVE_LOCKS (
   HL_LOCK_EXT_ID bigint NOT NULL,
   HL_LOCK_INT_ID bigint NOT NULL,
-  HL_TXNID bigint NOT NULL,
+  HL_TXNID bigint,
   HL_DB varchar(128) NOT NULL,
   HL_TABLE varchar(128),
   HL_PARTITION varchar(767),
@@ -1021,10 +861,6 @@ CREATE TABLE HIVE_LOCKS (
   HL_ACQUIRED_AT bigint,
   HL_USER varchar(128) NOT NULL,
   HL_HOST varchar(128) NOT NULL,
-  HL_HEARTBEAT_COUNT int,
-  HL_AGENT_INFO varchar(128),
-  HL_BLOCKEDBY_EXT_ID bigint,
-  HL_BLOCKEDBY_INT_ID bigint,
   PRIMARY KEY(HL_LOCK_EXT_ID, HL_LOCK_INT_ID),
   KEY HIVE_LOCK_TXNID_INDEX (HL_TXNID)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
@@ -1043,30 +879,9 @@ CREATE TABLE COMPACTION_QUEUE (
   CQ_PARTITION varchar(767),
   CQ_STATE char(1) NOT NULL,
   CQ_TYPE char(1) NOT NULL,
-  CQ_TBLPROPERTIES varchar(2048),
   CQ_WORKER_ID varchar(128),
   CQ_START bigint,
-  CQ_RUN_AS varchar(128),
-  CQ_HIGHEST_WRITE_ID bigint,
-  CQ_META_INFO varbinary(2048),
-  CQ_HADOOP_JOB_ID varchar(32)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE TABLE COMPLETED_COMPACTIONS (
-  CC_ID bigint PRIMARY KEY,
-  CC_DATABASE varchar(128) NOT NULL,
-  CC_TABLE varchar(128) NOT NULL,
-  CC_PARTITION varchar(767),
-  CC_STATE char(1) NOT NULL,
-  CC_TYPE char(1) NOT NULL,
-  CC_TBLPROPERTIES varchar(2048),
-  CC_WORKER_ID varchar(128),
-  CC_START bigint,
-  CC_END bigint,
-  CC_RUN_AS varchar(128),
-  CC_HIGHEST_WRITE_ID bigint,
-  CC_META_INFO varbinary(2048),
-  CC_HADOOP_JOB_ID varchar(32)
+  CQ_RUN_AS varchar(128)
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
 CREATE TABLE NEXT_COMPACTION_QUEUE_ID (
@@ -1074,101 +889,12 @@ CREATE TABLE NEXT_COMPACTION_QUEUE_ID (
 ) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 INSERT INTO NEXT_COMPACTION_QUEUE_ID VALUES(1);
 
-CREATE TABLE AUX_TABLE (
-  MT_KEY1 varchar(128) NOT NULL,
-  MT_KEY2 bigint NOT NULL,
-  MT_COMMENT varchar(255),
-  PRIMARY KEY(MT_KEY1, MT_KEY2)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
 
-CREATE TABLE WRITE_SET (
-  WS_DATABASE varchar(128) NOT NULL,
-  WS_TABLE varchar(128) NOT NULL,
-  WS_PARTITION varchar(767),
-  WS_TXNID bigint NOT NULL,
-  WS_COMMIT_ID bigint NOT NULL,
-  WS_OPERATION_TYPE char(1) NOT NULL
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE TABLE TXN_TO_WRITE_ID (
-  T2W_TXNID bigint NOT NULL,
-  T2W_DATABASE varchar(128) NOT NULL,
-  T2W_TABLE varchar(256) NOT NULL,
-  T2W_WRITEID bigint NOT NULL
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE UNIQUE INDEX TBL_TO_TXN_ID_IDX ON TXN_TO_WRITE_ID (T2W_DATABASE, T2W_TABLE, T2W_TXNID);
-CREATE UNIQUE INDEX TBL_TO_WRITE_ID_IDX ON TXN_TO_WRITE_ID (T2W_DATABASE, T2W_TABLE, T2W_WRITEID);
-
-CREATE TABLE NEXT_WRITE_ID (
-  NWI_DATABASE varchar(128) NOT NULL,
-  NWI_TABLE varchar(256) NOT NULL,
-  NWI_NEXT bigint NOT NULL
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE UNIQUE INDEX NEXT_WRITE_ID_IDX ON NEXT_WRITE_ID (NWI_DATABASE, NWI_TABLE);
-
-CREATE TABLE MIN_HISTORY_LEVEL (
-  MHL_TXNID bigint NOT NULL,
-  MHL_MIN_OPEN_TXNID bigint NOT NULL,
-  PRIMARY KEY(MHL_TXNID)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE INDEX MIN_HISTORY_LEVEL_IDX ON MIN_HISTORY_LEVEL (MHL_MIN_OPEN_TXNID);
-
-CREATE TABLE `I_SCHEMA` (
-  `SCHEMA_ID` BIGINT PRIMARY KEY,
-  `SCHEMA_TYPE` INTEGER NOT NULL,
-  `NAME` VARCHAR(256),
-  `DB_ID` BIGINT,
-  `COMPATIBILITY` INTEGER NOT NULL,
-  `VALIDATION_LEVEL` INTEGER NOT NULL,
-  `CAN_EVOLVE` bit(1) NOT NULL,
-  `SCHEMA_GROUP` VARCHAR(256),
-  `DESCRIPTION` VARCHAR(4000),
-  FOREIGN KEY (`DB_ID`) REFERENCES `DBS` (`DB_ID`),
-  KEY `UNIQUE_NAME` (`NAME`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE TABLE `SCHEMA_VERSION` (
-  `SCHEMA_VERSION_ID` bigint primary key,
-  `SCHEMA_ID` BIGINT,
-  `VERSION` INTEGER NOT NULL,
-  `CREATED_AT` BIGINT NOT NULL,
-  `CD_ID` BIGINT, 
-  `STATE` INTEGER NOT NULL,
-  `DESCRIPTION` VARCHAR(4000),
-  `SCHEMA_TEXT` mediumtext,
-  `FINGERPRINT` VARCHAR(256),
-  `SCHEMA_VERSION_NAME` VARCHAR(256),
-  `SERDE_ID` bigint, 
-  FOREIGN KEY (`SCHEMA_ID`) REFERENCES `I_SCHEMA` (`SCHEMA_ID`),
-  FOREIGN KEY (`CD_ID`) REFERENCES `CDS` (`CD_ID`),
-  FOREIGN KEY (`SERDE_ID`) REFERENCES `SERDES` (`SERDE_ID`),
-  KEY `UNIQUE_VERSION` (`SCHEMA_ID`, `VERSION`)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE TABLE REPL_TXN_MAP (
-  RTM_REPL_POLICY varchar(256) NOT NULL,
-  RTM_SRC_TXN_ID bigint NOT NULL,
-  RTM_TARGET_TXN_ID bigint NOT NULL,
-  PRIMARY KEY (RTM_REPL_POLICY, RTM_SRC_TXN_ID)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-
-CREATE TABLE RUNTIME_STATS (
-  RS_ID bigint primary key,
-  CREATE_TIME bigint NOT NULL,
-  WEIGHT bigint NOT NULL,
-  PAYLOAD blob
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
-
-CREATE INDEX IDX_RUNTIME_STATS_CREATE_TIME ON RUNTIME_STATS(CREATE_TIME);
 
 -- -----------------------------------------------------------------
 -- Record schema version. Should be the last step in the init script
 -- -----------------------------------------------------------------
-INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '3.0.0', 'Hive release version 3.0.0');
+INSERT INTO VERSION (VER_ID, SCHEMA_VERSION, VERSION_COMMENT) VALUES (1, '1.2.0', 'Hive release version 1.2.0');
 
 /*!40101 SET character_set_client = @saved_cs_client */;
 /*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;
